==> dde-daemon_5.13.12.orig.tar.xz: dde-daemon-5.13.12/misc/ts/com.deepin.daemon.accounts.policy/policy_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>ئۆزىڭىزنىڭ ئابونت سانلىق مەلۇماتىنى ئۆزگەرتىش ئۈچۈن سالاھىيىتىڭىزنى دەلىللەشكە توغرا كېلىدۇ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>ئۆزىڭىزنىڭ ئابونت سانلىق مەلۇماتىنى ئۆزگەرتىڭ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>ئابونىت سانلىق مەلۇماتىنى ئۆزگەرتىش ئۈچۈن سالاھىيەت سالاھىتىڭىزنى دەلىىللەڭ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>ئابونىت ھېسابات نۇمىرىنى باشقۇرۇش</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>ئاپتۇماتىك تىزىملاش ئۈچۈن سالاھىتىڭىزنى دەللىللەشكە توغرا كىلىدۇ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>ئېچىلغاندا ئاپتۇماتىك كىرىش</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>ئاپتۇماتىك كىرىشنى چەكلەش ئۈچۈن سالاھىيەت دەلىللەش كىرەك</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>ئاپتۇماتىك تىزىملاپ كىرىشنى چەكلەش</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>مەخپى نۇمۇرسىز كىرىش ئۈچۈن سالاھىيەت دەلىللەشكە توغرا كىلىدۇ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation> ئابونىت مەخپى شىفىرسىز كىرىش</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>مەخپى شىفىرسىز كىرىشنى توىتىتىش ئۈچۈن سالاھىيەت دەللىللەش كىرەك</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>مەخپى شىفىرسىز كىرىشنى چەكلەش</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>كۇنۇپكا تاختىسى ئورۇنلاشتۇرۇش ئۈچۈن سالاھىيىتىنى تەكشۈرۈشكە توغرا كېلىدۇ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>كونۇپكا تاختىىسى تەڭشەش</translation>
		</message>
	</context>
</TS>

==> dde-daemon_5.14.18.orig.tar.xz: dde-daemon-5.14.18/misc/ts/com.deepin.daemon.accounts.policy/policy_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>ئۆزىڭىزنىڭ ئابونت سانلىق مەلۇماتىنى ئۆزگەرتىش ئۈچۈن سالاھىيىتىڭىزنى دەلىللەشكە توغرا كېلىدۇ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>ئۆزىڭىزنىڭ ئابونت سانلىق مەلۇماتىنى ئۆزگەرتىڭ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>ئابونىت سانلىق مەلۇماتىنى ئۆزگەرتىش ئۈچۈن سالاھىيەت سالاھىتىڭىزنى دەلىىللەڭ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>ئابونىت ھېسابات نۇمىرىنى باشقۇرۇش</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>ئاپتۇماتىك تىزىملاش ئۈچۈن سالاھىتىڭىزنى دەللىللەشكە توغرا كىلىدۇ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>ئاپتۇماتىك كىرىشنى ئېچىش</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>ئاپتۇماتىك كىرىشنى تاقاش ئۈچۈن سالاھىيەت دەلىللەش كېرەك</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>ئاپتۇماتىك تىزىملاپ كىرىشنى چەكلەش</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>مەخپى نۇمۇرسىز كىرىش ئۈچۈن سالاھىيەت دەلىللەشكە توغرا كىلىدۇ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation> ئابونىت مەخپى شىفىرسىز كىرىش</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>مەخپى شىفىرسىز كىرىشنى توىتىتىش ئۈچۈن سالاھىيەت دەللىللەش كىرەك</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>مەخپى شىفىرسىز كىرىشنى چەكلەش</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>كۇنۇپكا تاختىسى ئورۇنلاشتۇرۇش ئۈچۈن سالاھىيىتىنى تەكشۈرۈشكە توغرا كېلىدۇ</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>كونۇپكا تاختىىسى تەڭشەش</translation>
		</message>
	</context>
</TS>
